#############
Fitting cubes
#############

This is what ``mcfine`` has been built for -- fitting datacubes. Here, we will detail some
simple cube fitting and exploration

.. toctree::
   :maxdepth: 2
   :caption: Cube Fitting

   fitting_a_cube
   exploring_cube_fits
